@@ -28,8 +28,9 @@ from functools import partial
 import logging
 log = logging.getLogger('mapproxy.config')
 
-from mapproxy.config import load_default_config, finish_base_config
-from mapproxy.config.spec import validate_mapproxy_conf
+from mapproxy.config import load_default_config, finish_base_config, defaults
+from mapproxy.config.validator import validate_references
+from mapproxy.config.spec import validate_options
 from mapproxy.util.py import memoize
 from mapproxy.util.ext.odict import odict
 from mapproxy.util.yaml import load_yaml_file, YAMLError
@@ -63,12 +64,9 @@ class ProxyConfiguration(object):
 
     def load_grids(self):
         self.grids = {}
-
-        self.grids['GLOBAL_GEODETIC'] = GridConfiguration(dict(srs='EPSG:4326', origin='sw', name='GLOBAL_GEODETIC'), context=self)
-        self.grids['GLOBAL_MERCATOR'] = GridConfiguration(dict(srs='EPSG:900913', origin='sw', name='GLOBAL_MERCATOR'), context=self)
-        self.grids['GLOBAL_WEBMERCATOR'] = GridConfiguration(dict(srs='EPSG:3857', origin='nw', name='GLOBAL_WEBMERCATOR'), context=self)
-
-        for grid_name, grid_conf in iteritems((self.configuration.get('grids') or {})):
+        grid_configs = dict(defaults.grids)
+        grid_configs.update(self.configuration.get('grids') or {})
+        for grid_name, grid_conf in iteritems(grid_configs):
             grid_conf.setdefault('name', grid_name)
             self.grids[grid_name] = GridConfiguration(grid_conf, context=self)
 
@@ -163,7 +161,7 @@ class ProxyConfiguration(object):
             if isinstance(layers_conf[0], dict) and len(layers_conf[0].keys()) == 1:
                 # looks like ordered legacy config
                 layers_conf = self._legacy_layers_conf_dict()
-            elif len(layers_conf) == 1 and 'layers' in layers_conf[0]:
+            elif len(layers_conf) == 1 and ('layers' in layers_conf[0] or 'sources' in layers_conf[0]):
                 # single root layer in list -> remove list
                 layers_conf = layers_conf[0]
             else:
@@ -946,7 +944,6 @@ class CacheConfiguration(ConfigurationBase):
 
         return FileCache(
             cache_dir,
-            lock_dir=self.lock_dir(),
             file_ext=file_ext,
             directory_layout=directory_layout,
             lock_timeout=lock_timeout,
@@ -1006,7 +1003,7 @@ class CacheConfiguration(ConfigurationBase):
         tile_id = self.conf['cache'].get('tile_id')
 
         return CouchDBCache(url=url, db_name=db_name,
-            lock_dir=self.lock_dir(), file_ext=file_ext, tile_grid=grid_conf.tile_grid(),
+            file_ext=file_ext, tile_grid=grid_conf.tile_grid(),
             md_template=md_template, tile_id_template=tile_id)
 
     def _riak_cache(self, grid_conf, file_ext):
@@ -1036,7 +1033,6 @@ class CacheConfiguration(ConfigurationBase):
 
         return RiakCache(nodes=nodes, protocol=protocol, bucket=bucket,
             tile_grid=grid_conf.tile_grid(),
-            lock_dir=self.lock_dir(),
             use_secondary_index=use_secondary_index,
         )
 
@@ -1564,6 +1560,7 @@ class ServiceConfiguration(ConfigurationBase):
         from mapproxy.request.wms import Version
 
         md = conf.get('md', {})
+        inspire_md = conf.get('inspire_md', {})
         tile_layers = self.tile_layers(conf)
         attribution = conf.get('attribution')
         strict = self.context.globals.get_value('strict', conf, global_key='wms.strict')
@@ -1611,7 +1608,9 @@ class ServiceConfiguration(ConfigurationBase):
             srs=srs, tile_layers=tile_layers, strict=strict, on_error=on_source_errors,
             concurrent_layer_renderer=concurrent_layer_renderer,
             max_output_pixels=max_output_pixels, srs_extents=srs_extents,
-            max_tile_age=max_tile_age, versions=versions)
+            max_tile_age=max_tile_age, versions=versions,
+            inspire_md=inspire_md,
+            )
 
         server.fi_transformers = fi_xslt_transformers(conf, self.context)
 
@@ -1649,6 +1648,12 @@ class ServiceConfiguration(ConfigurationBase):
             if restful:
                 services.append('wmts_restful')
 
+        if 'wms' in self.context.services.conf:
+            versions = self.context.services.conf['wms'].get('versions', ['1.1.1'])
+            if '1.1.1' in versions:
+                # demo service only supports 1.1.1, use wms_111 as an indicator
+                services.append('wms_111')
+
         return DemoServer(layers, md, tile_layers=tile_layers,
             image_formats=image_formats, srs=srs, services=services, restful_template=restful_template)
 
@@ -1656,15 +1661,29 @@ class ServiceConfiguration(ConfigurationBase):
 def load_configuration(mapproxy_conf, seed=False, ignore_warnings=True, renderd=False):
     conf_base_dir = os.path.abspath(os.path.dirname(mapproxy_conf))
 
+    # A configuration is checked/validated four times, each step has a different
+    # focus and returns different errors. The steps are:
+    # 1. YAML loading: checks YAML syntax like tabs vs. space, indention errors, etc.
+    # 2. Options: checks all options agains the spec and validates their types,
+    #             e.g is disable_storage a bool, is layers a list, etc.
+    # 3. References: checks if all referenced caches, sources and grids exist
+    # 4. Initialization: creates all MapProxy objects, returns on first error
+
     try:
         conf_dict = load_configuration_file([os.path.basename(mapproxy_conf)], conf_base_dir)
     except YAMLError as ex:
         raise ConfigurationError(ex)
-    errors, informal_only = validate_mapproxy_conf(conf_dict)
+
+    errors, informal_only = validate_options(conf_dict)
     for error in errors:
         log.warn(error)
     if not informal_only or (errors and not ignore_warnings):
         raise ConfigurationError('invalid configuration')
+
+    errors = validate_references(conf_dict)
+    for error in errors:
+        log.warn(error)
+
     return ProxyConfiguration(conf_dict, conf_base_dir=conf_base_dir, seed=seed,
         renderd=renderd)
 
