@@ -1,3 +1,4 @@
+# -:- encoding: UTF8 -:-
 # This file is part of the MapProxy project.
 # Copyright (C) 2010 Omniscale <http://omniscale.de>
 #
@@ -13,6 +14,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from __future__ import print_function
+
 from mapproxy.srs import SRS
 from mapproxy.request.base import url_decode, Request, NoCaseMultiDict, RequestParams
 from mapproxy.request.tile import TMSRequest, tile_request, TileRequest
@@ -31,7 +34,7 @@ class TestNoCaseMultiDict(object):
     def test_from_iterable(self):
         data = (('layers', 'foo,bar'), ('laYERs', 'baz'), ('crs', 'EPSG:4326'))
         nc_dict = NoCaseMultiDict(data)
-        print nc_dict
+        print(nc_dict)
 
         for name in ('layers', 'LAYERS', 'lAYeRS'):
             assert name in nc_dict, name + ' not found'
@@ -41,7 +44,7 @@ class TestNoCaseMultiDict(object):
     def test_from_dict(self):
         data = [('layers', 'foo,bar'), ('laYERs', 'baz'), ('crs', 'EPSG:4326')]
         nc_dict = NoCaseMultiDict(data)
-        print nc_dict
+        print(nc_dict)
 
         for name in ('layers', 'LAYERS', 'lAYeRS'):
             assert name in nc_dict, name + ' not found'
@@ -49,15 +52,16 @@ class TestNoCaseMultiDict(object):
         assert nc_dict.get_all('crs') == ['EPSG:4326']
 
     def test_iteritems(self):
-        data = dict([('LAYERS', 'foo,bar'), ('laYERs', 'baz'), ('crs', 'EPSG:4326')])
+        data = [('LAYERS', 'foo,bar'), ('laYERs', 'baz'), ('crs', 'EPSG:4326')]
         nc_dict = NoCaseMultiDict(data)
-        print nc_dict
 
-        itr = nc_dict.iteritems()
-        key, values = itr.next()
-        assert key == 'LAYERS' and values == ['foo,bar', 'baz']
-        key, values = itr.next()
-        assert key == 'crs' and values == ['EPSG:4326']
+        for key, values in nc_dict.iteritems():
+            if key in ('LAYERS', 'laYERs'):
+                assert values == ['foo,bar', 'baz']
+            elif key == 'crs':
+                assert values == ['EPSG:4326']
+            else:
+                assert False, 'unexpected key ' + key
 
     def test_multiple_sets(self):
         nc_dict = NoCaseMultiDict()
@@ -247,14 +251,15 @@ class TestRequest(object):
     def test_query_string(self):
         self.env['QUERY_STRING'] = 'Foo=boo&baz=baa&fOO=bizz'
         req = Request(self.env)
-        print req.args['foo']
+        print(req.args['foo'])
         assert req.args.get_all('foo') == ['boo', 'bizz']
+
     def test_query_string_encoding(self):
         env = {
             'QUERY_STRING': 'foo=some%20special%20chars%20%26%20%3D'
         }
         req = Request(env)
-        print req.args['foo']
+        print(req.args['foo'])
         assert req.args['foo'] == u'some special chars & ='
 
     def test_script_url(self):
@@ -343,7 +348,7 @@ class TestWMSMapRequestParams(object):
         self.m['bgcolor'] = '0x42cafe'
         assert self.m.bgcolor == '#42cafe'
     def test_srs(self):
-        print self.m.srs
+        print(self.m.srs)
         assert self.m.srs == 'EPSG:0815'
         del self.m['srs']
         assert self.m.srs is None
@@ -352,10 +357,13 @@ class TestWMSMapRequestParams(object):
     def test_layers(self):
         assert list(self.m.layers) == ['bar', 'foo']
     def test_query_string(self):
-        print self.m.query_string
         assert_query_eq(self.m.query_string,
             'layers=bar,foo&WIdth=100&bBOx=-90,-80,70.0,+80'
             '&format=image%2Fpng&srs=EPSG%3A0815&heIGHT=200')
+    def test_query_string_encoding(self):
+        m = WMSMapRequestParams()
+        m.layers = ["layer with whitespace", u"layer with ümlauts"]
+        eq_(m.query_string, 'layers=layer%20with%20whitespace,layer%20with%20%C3%BCmlauts')
     def test_get(self):
         assert self.m.get('LAYERS') == 'bar'
         assert self.m.get('width', type_func=int) == 100
@@ -419,7 +427,7 @@ BBOX=8,4,9,5&WIDTH=984&HEIGHT=708""".replace('\n', ''))
         del self.req.args['request']
         try:
             wms_request(self.req)
-        except RequestError, e:
+        except RequestError as e:
             assert 'request' in e.msg
         else:
             assert False, 'RequestError expected'
